package com.xtd.project.assets.service;

import com.xtd.project.assets.domain.DbAssetsStockAllot;
import com.xtd.project.assets.domain.DbAssetsStockAllotVo;

import java.util.List;

/**
 * 资产调拨Service接口
 *
 * @author xtd
 * @date 2020-04-20
 */
public interface IDbAssetsStockAllotService
{
    /**
     * 查询资产调拨
     *
     * @param aId 资产调拨ID
     * @return 资产调拨
     */
    public DbAssetsStockAllot selectDbAssetsStockAllotById(Long aId);

    /**
     * 查询资产调拨列表
     *
     * @param dbAssetsStockAllotForm 资产调拨
     * @return 资产调拨集合
     */
    public List<DbAssetsStockAllotVo> selectDbAssetsStockAllotList(DbAssetsStockAllotVo dbAssetsStockAllotForm);

    /**
     * 新增资产调拨
     *
     * @param dbAssetsStockAllot 资产调拨
     * @return 结果
     */
    public int insertDbAssetsStockAllot(DbAssetsStockAllot dbAssetsStockAllot);

    /**
     * 修改资产调拨
     *
     * @param dbAssetsStockAllot 资产调拨
     * @return 结果
     */
    public int updateDbAssetsStockAllot(DbAssetsStockAllot dbAssetsStockAllot);

    /**
     * 批量删除资产调拨
     *
     * @param aIds 需要删除的资产调拨ID
     * @return 结果
     */
    public int deleteDbAssetsStockAllotByIds(Long[] aIds);

    /**
     * 删除资产调拨信息
     *
     * @param aId 资产调拨ID
     * @return 结果
     */
    public int deleteDbAssetsStockAllotById(Long aId);

    void commit(Long aId, String processId);

    void recommit(DbAssetsStockAllot dbAssetsStockAllot);
}
